const path = require("path");

module.exports = {
  rulesDirectory: [
    path.join(
      path.dirname(require.resolve("tslint-consistent-codestyle")),
      "./"
    ),
    path.join(path.dirname(require.resolve("tslint-react")), "./"),
    path.join(
      path.dirname(require.resolve("tslint-eslint-rules")),
      "dist/rules"
    ),
    path.join(path.dirname(require.resolve("tslint-microsoft-contrib")), "./")
  ],
  rules: {
    // TypeScript specific,
    "no-var-keyword": true,

    //Functionality
    curly: [true, "ignore-same-line"],
    "no-construct": true,
    "no-eval": true,
    "no-parameter-reassignment": true,
    "no-this-assignment": [true, "allow-destructuring"],
    "no-floating-promises": true,
    "no-invalid-this": true,
    "no-object-literal-type-assertion": true,
    "no-invalid-template-strings": true,
    "no-shadowed-variable": [
      true,
      {
        class: true,
        enum: true,
        function: true,
        interface: false,
        namespace: true,
        typeAlias: false,
        typeParameter: false,
        underscore: false
      }
    ],
    "no-return-await": true,
    "no-switch-case-fall-through": true,
    "no-void-expression": [true, "ignore-arrow-function-shorthand"],
    "prefer-object-spread": true,
    radix: true,
    "ter-prefer-arrow-callback": [true],
    "triple-equals": true,
    // "unnecessary-constructor": true,
    "use-isnan": true,

    //Maintainability
    deprecation: true,
    "cyclomatic-complexity": true,
    "no-duplicate-imports": true,
    "prefer-const": true,

    //Style
    "brace-style": [true, "1tbs", { allowSingleLine: true }],
    "comment-format": [true, "check-space"],
    "class-name": true,
    "function-name": [
      true,
      {
        "function-regex": /^[a-z$][\w\d]+$/,
        "method-regex": /^[a-z$][\w\d]+$/,
        "private-method-regex": /^_[a-z$][\w\d]+$/,
        "protected-method-regex": /^[a-z$][\w\d]+$/,
        "static-method-regex": /^[a-z$][\w\d]+$/
      }
    ],
    "no-boolean-literal-compare": true,
    "no-else-after-return": true,
    "object-literal-shorthand": true,
    "object-shorthand-properties-first": true,
    "object-literal-key-quotes": [true, "as-needed"],
    "one-variable-per-declaration": true,
    "prefer-array-literal": true,
    "prefer-template": true,
    // "unnecessary-bind": true,
    quotemark: [true, "single", "avoid-escape", "avoid-template", "jsx-double"],
    "space-before-function-paren": [
      true,
      {
        anonymous: "always",
        named: "never"
      }
    ],
    "variable-name": [
      true,
      "ban-keywords",
      "check-format",
      "allow-leading-underscore",
      "allow-pascal-case"
    ],

    //Format
    align: [true, "arguments", "parameters"],
    "arrow-parens": false,
    "ter-arrow-parens": [true, "as-needed", { requireForBlockBody: true }],
    indent: [true, "spaces"],
    whitespace: [
      true,
      "check-branch",
      "check-decl",
      "check-operator",
      "check-preblock",
      "check-separator"
    ],
    eofline: false,
    "space-in-parens": [false, "never"],
    "array-bracket-spacing": [true, "never"],
    "object-curly-spacing": [true, "always"],
    "max-line-length": [true, 100],
    "block-spacing": true,
    "ter-computed-property-spacing": true,
    "ter-func-call-spacing": true,
    "no-trailing-whitespace": true,
    "no-consecutive-blank-lines": true,
    "trailing-comma": [
      true,
      {
        multiline: "always",
        singleline: "never",
        esSpecCompliant: true
      }
    ],
    semicolon: [true, "always"],

    // React
    "jsx-key": true,
    "jsx-no-bind": true,
    "jsx-no-lambda": true,
    "jsx-no-string-ref": true,
    "jsx-self-close": true,
    "jsx-wrap-multiline": true
  }
};
